@@ -29,6 +29,12 @@ if (( $(crontab -l | grep -c "{{ hchk }}" ) == 0 )) ; then
         env >> _cron
     fi
     echo "{{ time }} $PWD/cron/Crontask.sh -i {{ hchk }} -l $HOME/app/log/ null null cmd "\""$PWD/cron/{{ jobName }}"\""" >> _cron
-    crontab _cron
-    rm -f _cron
+    if crontab _cron; then
+        rm -rf _cron
+    else
+        rm -rf _cron
+        exit 1
+    fi
+else
+    echo "Job existed. Nothing to do"
 fi
\ No newline at end of file
