@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 12720 2021-01-31 06:51:53Z Casey $
+# $Id: admin.py 12748 2021-02-06 05:31:58Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-01-31 14:51:53 +0800 (Sun, 31 Jan 2021) $
-# $Revision: 12720 $
+# $Date: 2021-02-06 13:31:58 +0800 (Sat, 06 Feb 2021) $
+# $Revision: 12748 $
 
 import os
 import datetime
@@ -53,18 +53,15 @@ TEXT_SUB_FILE_NAME = [
 IMAGE_SUB_FILE_NAME = [
     'jpg', 'png', 'jpeg', 'bmp', 'gif', 'tif',
 ]
-FILE_SUB_FILE_NAME = [
-    'xlsx',
-]
 
 logger = createLogger(__name__)
 
-class FolderFrom(forms.ModelForm):
+class FolderForm(forms.ModelForm):
     class Meta(object):
         model = Static
         exclude = ('parent', 'type', 'name')
 
-class FileFrom(forms.ModelForm):
+class FileForm(forms.ModelForm):
     file = forms.FileField(
         label=_('File'), required=False)
 
@@ -72,7 +69,7 @@ class FileFrom(forms.ModelForm):
         model = Static
         exclude = ('parent', 'type', 'name')
 
-class TextFrom(forms.ModelForm):
+class TextForm(forms.ModelForm):
     content = forms.CharField(
         label=_('Content'), widget=forms.Textarea, required=False)
 
@@ -80,7 +77,7 @@ class TextFrom(forms.ModelForm):
         model = Static
         exclude = ('parent', 'type', 'name')
 
-class ImageFrom(forms.ModelForm):
+class ImageForm(forms.ModelForm):
     image = forms.ImageField(label=_('Image'), required=False)
 
     class Meta(object):
@@ -118,8 +115,8 @@ def createVersion(model, node, conflict=False):
                     os.stat(preVersion.absoluteBackupPath).st_mtime)
                 currentFileUpdateTime = datetime.datetime.fromtimestamp(
                     os.stat(fullPath).st_mtime)
-                
-                if preVersionUpdateTime < currentFileUpdateTime: 
+
+                if preVersionUpdateTime < currentFileUpdateTime:
                     # 當前檔案比版控最新版本的新時，建立新版本並判斷是否衝突
                     if not maxVersion == 0 or not conflict:
                         version = Version.objects.create(
@@ -156,25 +153,25 @@ def createVersion(model, node, conflict=False):
                 "Template Editor: %s's version backup files had be deleted. "
                 "create new versions for %s" % (node.name, node.name)
             )
-            
+
             # delete all version
             Version.objects.filter(dirName=dirName).delete()
-            
+
             # 重新建 version
             maxVersion = 0
-            
+
             if subFileName:
                 backupName = "%s_%d.%s" % (fileName, maxVersion, subFileName)
             else:
                 backupName = "%s_%d" % (fileName, maxVersion)
-                
+
             version = Version.objects.create(
                 dirName=dirName,
                 checksum=checksum,
                 number=maxVersion,
                 fileName=backupName,
             )
-            createFile = True 
+            createFile = True
     else:
         # 沒有 version，建 version
         maxVersion = 0
@@ -189,7 +186,7 @@ def createVersion(model, node, conflict=False):
             number=maxVersion,
             fileName=backupName,
         )
-        createFile = True 
+        createFile = True
 
     if createFile:
         dirPath = os.path.join(BACKUP_FILE_DIR, dirName)
@@ -208,7 +205,7 @@ def checkVersion(model):
     # 確保 BACKUP_FILE_DIR 存在
     if not os.path.isdir(BACKUP_FILE_DIR):
         os.mkdir(BACKUP_FILE_DIR)
-        
+
     conflictNodeList = []
     for node in model.objects.filter(type=FILE):
         version = createVersion(model, node, conflict=True)
@@ -223,7 +220,7 @@ def checkVersion(model):
                 path, version.number, version.preVersion.number))
 
     return conflictNodeList
-    
+
 def getConflictNodeList(model):
     conflictNodeList = []
     nodeList = model.objects.filter(type=FILE)
@@ -234,7 +231,7 @@ def getConflictNodeList(model):
         node = dirNameNodeTable[version.dirName]
         conflictNodeList.append((node, version))
     return conflictNodeList
-        
+
 
 def loginCheck(sender, user, request, **kwargs):
     if user.is_superuser:
@@ -248,7 +245,7 @@ def loginCheck(sender, user, request, **kwargs):
             msg = _("Version %(version)d "
                     "conflict Version %(preVersion)d !!: "
                     "<a href='%(url)s'>%(path)s</a>") % {
-                    'version': version.number, 
+                    'version': version.number,
                     'preVersion': version.preVersion.number,
                     'url': url,
                     'path': node.path,
@@ -282,10 +279,10 @@ class BaseFileAdmin(admin.ModelAdmin):
             return update_wrapper(wrapper, view)
 
         info = self.model._meta.app_label, self.model._meta.model_name
-        
+
         urlpatterns = [
-            url(r'^version/(?P<id>.+)/removeConflict/$', 
-                wrap(self.removeConflictView), 
+            url(r'^version/(?P<id>.+)/removeConflict/$',
+                wrap(self.removeConflictView),
                 name="%s_%s_removeConflict" % info),
         ] + super(BaseFileAdmin, self).get_urls()
 
@@ -309,7 +306,7 @@ class BaseFileAdmin(admin.ModelAdmin):
 
         # is folder
         if obj.type == FOLDER:
-            return FolderFrom
+            return FolderForm
 
         # is file
         versionNum = request.GET.get('version', None)
@@ -322,16 +319,14 @@ class BaseFileAdmin(admin.ModelAdmin):
         subFileName = obj.subFileName
 
         if subFileName in TEXT_SUB_FILE_NAME:
-            form = TextFrom
+            form = TextForm
             with open(fullPath, 'rb') as f:
                 data = f.read()
             form.base_fields['content'].initial = data
         elif subFileName in IMAGE_SUB_FILE_NAME:
-            form = ImageFrom
-        elif subFileName in FILE_SUB_FILE_NAME:
-            form = FileFrom
+            form = ImageForm
         else:
-            form = FolderFrom
+            form = FileForm
 
         return form
 
@@ -373,13 +368,13 @@ class BaseFileAdmin(admin.ModelAdmin):
             if subFileName in TEXT_SUB_FILE_NAME:
                 # 能支援上傳修改檔案
                 content = request.POST.get('content')
-                
+
                 with open(fullPath, 'wb') as f:
                     data = f.write(content.encode('utf-8'))
             elif subFileName in IMAGE_SUB_FILE_NAME:
                 # 圖片轉檔
                 image = request.FILES.get('image')
-                
+
                 if image:
                     data = image.read()
                     image.close()
@@ -390,13 +385,13 @@ class BaseFileAdmin(admin.ModelAdmin):
                     backupPath = version.absoluteBackupPath
                     with open(backupPath, 'rb') as f:
                         data = f.read()
-                    
+
                     with open(fullPath, 'wb') as f:
                         data = f.write(data)
                 else:
                     pass
 
-            elif subFileName in FILE_SUB_FILE_NAME:
+            else:
                 file = request.FILES.get('file')
 
                 with open(fullPath, 'wb') as f:
@@ -408,7 +403,7 @@ class BaseFileAdmin(admin.ModelAdmin):
         # reload loader
         for engine in engines.all():
             for loader in engine.engine.template_loaders:
-                if (hasattr(loader, 'template_cache') and hasattr(loader, 'find_template_cache') 
+                if (hasattr(loader, 'template_cache') and hasattr(loader, 'find_template_cache')
                     and hasattr(loader, 'get_template_cache')):
                     # for cache loader
                     key = loader.cache_key(obj.path, None)
@@ -417,19 +412,19 @@ class BaseFileAdmin(admin.ModelAdmin):
                     loader.get_template_cache.pop(key, None)
                 else:
                     loader.reset()
-        
+
         return super(BaseFileAdmin, self).response_change(request, obj)
 
     def changelist_view(self, request, extra_context=None):
         conflictNodeList = getConflictNodeList(self.model)
 
         roots = self.model.objects.filter(level=0)
-         
+
         extra_context = {
             'roots': roots,
             'conflictNodeList': conflictNodeList,
         }
-        
+
         return super(BaseFileAdmin, self).changelist_view(
             request,  extra_context=extra_context)
 
@@ -440,4 +435,4 @@ class TemplateAdmin(BaseFileAdmin):
     pass
 
 admin.site.register(Static, StaticAdmin)
-admin.site.register(Template, TemplateAdmin)
\ No newline at end of file
+admin.site.register(Template, TemplateAdmin)
