@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # $Id: AttachSettingsTest.py 11172 2018-07-16 09:31:00Z Lavender $
 #
-# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2020 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -17,12 +17,14 @@
 
 import os
 import sys
+import requests
 import subprocess
 
 from lxml import etree
 
 from django.http import HttpResponse, JsonResponse
 from django.views.decorators.csrf import csrf_exempt
+from django.conf import settings
 
 from Iuno.Version import IUNO_VERSION
 
@@ -58,8 +60,8 @@ def getTestcaseReport():
 @csrf_exempt
 def test(request):
     if request.POST.get("password") == "25025529":
-        
         if request.POST.get("settings"):
+            
             resultCode = subprocess.call(
                 "python manage.py testall --settings %s > test.log" % request.POST.get("settings"), shell=True)
         else:
@@ -72,6 +74,7 @@ def test(request):
         track = getTestcaseReport()
             
         data = {
+            'APP_VERSION': getattr(settings, "APP_VERSION", None),
             'IUNO_VERSION': IUNO_VERSION,
             'result': result,
             'resultCode': resultCode,
